##########
GameFinder
##########

GameFinder will search through files on disc, grouping up by game which includes potential duplicate ROM files (e.g.
games with slightly different names in different regions)

For more details on the GameFinder arguments, see the :doc:`config file documentation <../configs/config>`.

API
===

.. autoclass:: romsearch.GameFinder
    :no-index:
    :members:
    :undoc-members: